Struct ExtendUsing

pub struct ExtendUsing<F: ?Sized>(pub F);
Use an arbitrary FnMut type to implement Extend.

use extend_fn::ExtendUsing; 

let numbers = [5, 2, 11usize];

let mut result = 1usize; 
let mut extender = ExtendUsing::new(|value| result *= value);
extender.extend(numbers.iter().copied());

assert_eq!(numbers.iter().product::<usize>(), result);

For cases where you are writing into an actual container and want to transform items before their addition, consider using the extend_map crate instead.

Tuple Fields

0: F

Implementations

Source

impl<F> ExtendUsing<F>

pub const fn new(f: F) -> Self